@@ -347,13 +347,13 @@ def prepare_host_id_batches_for_host_list_detection_04_extract(
 
     batch_number = 1
     batch_size_counter = 0
-    batch_size_max = 2000
+    batch_size_max = int(etld_lib_config.host_list_detection_multi_proc_batch_size)
 
-    if int(etld_lib_config.host_list_detection_multi_proc_batch_size) > 2000:
-        etld_lib_functions.logger.info(f"reset batch_size_max to 2000.")
-        etld_lib_functions.logger.info(f" user select batch_size_max was "
-                                       f"{etld_lib_config.host_list_detection_multi_proc_batch_size}.")
-        etld_lib_config.host_list_detection_multi_proc_batch_size = 2000
+    # if int(etld_lib_config.host_list_detection_multi_proc_batch_size) > 2000:
+    #     etld_lib_functions.logger.info(f"reset batch_size_max to 2000.")
+    #     etld_lib_functions.logger.info(f" user select batch_size_max was "
+    #                                    f"{etld_lib_config.host_list_detection_multi_proc_batch_size}.")
+    #     etld_lib_config.host_list_detection_multi_proc_batch_size = 2000
 
     host_id_list = []
     for ID, DATETIME in host_list_records:
