@@ -87,6 +87,8 @@ def drop_and_create_all_tables(sqlite_obj):
     A.LAST_VM_AUTH_SCANNED_DURATION HL_LAST_VM_AUTH_SCANNED_DURATION, 
     A.LAST_COMPLIANCE_SCAN_DATETIME HL_LAST_COMPLIANCE_SCAN_DATETIME, A.OWNER HL_OWNER, 
     A.COMMENTS HL_COMMENTS, A.USER_DEF HL_USER_DEF, A.ASSET_GROUP_IDS HL_ASSET_GROUP_IDS, 
+    A.ASSET_RISK_SCORE HL_ASSET_RISK_SCORE, A.ASSET_CRITICALITY_SCORE HL_ASSET_CRITICALITY_SCORE,
+    A.ARS_FACTORS HL_ARS_FACTORS,
     A.BATCH_DATE HL_BATCH_DATE, A.BATCH_NUMBER HL_BATCH_NUMBER, A.Row_Last_Updated HL_Row_Last_Updated, 
     B.ID HLDH_ID, B.ASSET_ID HLDH_ASSET_ID, B.IP HLDH_IP, B.IPV6 HLDH_IPV6, B.TRACKING_METHOD HLDH_TRACKING_METHOD, 
     B.NETWORK_ID HLDH_NETWORK_ID, B.OS HLDH_OS, B.OS_CPE HLDH_OS_CPE, B.DNS HLDH_DNS, B.DNS_DATA HLDH_DNS_DATA, 
@@ -107,6 +109,7 @@ def drop_and_create_all_tables(sqlite_obj):
     C.IS_DISABLED HLDQ_IS_DISABLED, C.AFFECT_RUNNING_KERNEL HLDQ_AFFECT_RUNNING_KERNEL, 
     C.AFFECT_RUNNING_SERVICE HLDQ_AFFECT_RUNNING_SERVICE, 
     C.AFFECT_EXPLOITABLE_CONFIG HLDQ_AFFECT_EXPLOITABLE_CONFIG, 
+    C.QDS HLDQ_QDS, C.QDS_FACTORS HLDQ_QDS_FACTORS,
     C.RESULTS HLDQ_RESULTS, 
     C.BATCH_DATE HLDQ_BATCH_DATE, 
     C.BATCH_NUMBER HLDQ_BATCH_NUMBER, 
@@ -276,8 +279,8 @@ def insert_xml_file_into_sqlite(xml_file, sqlite_obj: etld_lib_sqlite_tables.Sql
             batch_date = etld_lib_extract_transform_load.get_batch_date_from_filename(xml_file)
             batch_number = etld_lib_extract_transform_load.get_batch_number_from_filename(xml_file)
             try:
-                if document_item['ID'] == '168327708':
-                    print()
+                # if document_item['ID'] == '168327708':
+                #     print()
                 insert_into_sqlite_host_list_detection_host_and_associated_qids(
                     host_list_detection_document=document_item, sqlite_obj=sqlite_obj,
                     batch_date=batch_date, batch_number=int(batch_number), counter_obj=counter_obj)
