@@ -1392,11 +1392,13 @@ def asset_inventory_csv_columns():  # Return list of csv columns updated 0.6.111
         'sensor_lastVMScanDate', 'sensor_lastComplianceScanDate', 'sensor_lastFullScanDate', 'inventory_createdDate',
         'inventory_lastUpdatedDate', 'agent_lastActivityDate', 'agent_lastCheckedInDate', 'agent_lastInventoryDate',
         'assetType', 'address', 'dnsName', 'assetName', 'netbiosName', 'timeZone', 'biosDescription', 'lastBoot',
-        'totalMemory', 'cpuCount', 'lastLoggedOnUser', 'hwUUID', 'biosSerialNumber', 'biosAssetTag', 'isContainerHost',
+        'totalMemory', 'cpuCount', 'lastLoggedOnUser', 'domainRole', 'hwUUID', 'biosSerialNumber', 'biosAssetTag', 'isContainerHost',
         'operatingSystem', 'hardware', 'userAccountListData', 'openPortListData', 'volumeListData',
         'networkInterfaceListData', 'softwareListData', 'provider', 'cloudProvider', 'agent', 'sensor', 'container',
-        'inventory', 'activity', 'tagList', 'serviceList', 'lastLocation', 'processor', 'criticality',
-        'businessInformation', 'assignedLocation', 'businessAppListData', 'TRUNCATED_FIELD_LIST'
+        'inventory', 'activity', 'tagList', 'serviceList', 'lastLocation', 'criticality',
+        'businessInformation', 'assignedLocation', 'businessAppListData',
+        'riskScore', 'passiveSensor', 'domain', 'subdomain', 'whois', 'isp', 'asn',
+        'processor', 'TRUNCATED_FIELD_LIST'
                    ]
     return csv_columns
 
@@ -1476,6 +1478,18 @@ def log_ram_disk_stats():
         logger_method=etld_lib_functions.logger.warn)
 
 
+def check_swap_space():
+    etld_lib_functions.if_swap_space_total_is_low_log_warning(
+        logger_method=etld_lib_functions.logger.warn
+    )
+
+
+def check_ram_space():
+    etld_lib_functions.if_ram_space_size_is_low_log_warning(
+        logger_method=etld_lib_functions.logger.warn
+    )
+
+
 def main():
     get_qetl_code_dir()
     setup_user_home_directories()
