@@ -259,102 +259,102 @@ def get_cookie(update_cookie=True):
     return cookie
 
 
-def get_bearer(update_bearer=True):
-    one_hour = (60*60)  # (Sec * Min)
-    try:
-        if update_bearer is True:
-            qualys_gateway_login()
-        if Path(bearer_file).is_file():
-            age_of_file = etld_lib_datetime.get_seconds_since_last_file_modification(Path(bearer_file))
-            if age_of_file > one_hour:
-                qualys_gateway_login()
-        else:
-            qualys_gateway_login()
-
-        with open(bearer_file, 'r', encoding='utf-8') as f:
-            bearer = f.read().replace('\n', '').replace('\r', '')
-        bearer_file_mode = stat.filemode(os.stat(bearer_file).st_mode)
-        etld_lib_functions.logger.info(f"Bearer Set, Ensure perms are correct for your company. "
-                                       f"permissions: {bearer_file_mode}, bearer file: {str(bearer_file)} ")
-    except Exception as e:
-        etld_lib_functions.logger.error(f"               Credentials Dir:  {cred_dir}")
-        etld_lib_functions.logger.error(f"              Credentials File:  {cred_file}")
-        etld_lib_functions.logger.error(f"Exception: {e}")
-        exit(1)
-
-    return bearer
+# def get_bearer(update_bearer=True):
+#     one_hour = (60*60)  # (Sec * Min)
+#     try:
+#         if update_bearer is True:
+#             qualys_gateway_login()
+#         if Path(bearer_file).is_file():
+#             age_of_file = etld_lib_datetime.get_seconds_since_last_file_modification(Path(bearer_file))
+#             if age_of_file > one_hour:
+#                 qualys_gateway_login()
+#         else:
+#             qualys_gateway_login()
+#
+#         with open(bearer_file, 'r', encoding='utf-8') as f:
+#             bearer = f.read().replace('\n', '').replace('\r', '')
+#         bearer_file_mode = stat.filemode(os.stat(bearer_file).st_mode)
+#         etld_lib_functions.logger.info(f"Bearer Set, Ensure perms are correct for your company. "
+#                                        f"permissions: {bearer_file_mode}, bearer file: {str(bearer_file)} ")
+#     except Exception as e:
+#         etld_lib_functions.logger.error(f"               Credentials Dir:  {cred_dir}")
+#         etld_lib_functions.logger.error(f"              Credentials File:  {cred_file}")
+#         etld_lib_functions.logger.error(f"Exception: {e}")
+#         exit(1)
+#
+#     return bearer
 
 
-def qualys_gateway_login_test():
-    two_hours = (60*60)*2  # (Sec * Min) * 2 for two hours in seconds
-    if Path(bearer_file).is_file():
-        age_of_file = etld_lib_datetime.get_seconds_since_last_file_modification(Path(bearer_file))
-        if age_of_file > two_hours:
-            qualys_gateway_login()
-    else:
-        qualys_gateway_login()
+# def qualys_gateway_login_test():
+#     two_hours = (60*60)*2  # (Sec * Min) * 2 for two hours in seconds
+#     if Path(bearer_file).is_file():
+#         age_of_file = etld_lib_datetime.get_seconds_since_last_file_modification(Path(bearer_file))
+#         if age_of_file > two_hours:
+#             qualys_gateway_login()
+#     else:
+#         qualys_gateway_login()
 
 
-def qualys_gateway_login():
-    global login_gateway_failed
-    global http_return_code
-
-    login_gateway_failed = True
-    cred_dict = get_cred()
-    if cred_dict['gateway_fqdn_server'] is None:
-        etld_lib_functions.logger.error(f"Please add gateway_fqdn_server to your credentials file.")
-        exit(1)
-
-    # Login to Qualys, return bearer token.
-    url = f"https://{cred_dict['gateway_fqdn_server']}/auth"  # Qualys Endpoint
-    payload = {'token': 'true', 'password': cred_dict['password'], 'username': cred_dict['username'],
-               'permissions': 'true'}
-    payload = urlencode(payload, quote_via=quote_plus)
-
-    headers = {'X-Requested-With': f'qualysetl_v{qualys_etl.__version__}',
-               'Content-Type': 'application/x-www-form-urlencoded',
-               'User-Agent': f"qualysetl_v{qualys_etl.__version__}"}
-
-    try:
-        if Path(bearer_file).is_file():
-            Path(bearer_file).unlink()
-        response = requests.request("POST", url, headers=headers, data=payload,
-                                    verify=etld_lib_config.requests_module_tls_verify_status)
-        http_return_code = response.status_code
-        if response.status_code == 201:
-            bearer = f"Bearer {response.text}"
-            with open(bearer_file, 'w', encoding='utf-8') as bearerfile:
-                bearerfile.write(bearer)
-            oschmod.set_mode(str(bearer_file), "u+rw,u-x,go-rwx")
-            etld_lib_functions.logger.info(f"LOGIN - Qualys Gateway Login Success with user: {cred_dict['username']}")
-            bearer_file_mode = stat.filemode(os.stat(bearer_file).st_mode)
-            etld_lib_functions.logger.info(f"Bearer Set, Ensure perms are correct for your company. "
-                                           f"permissions: {bearer_file_mode}, bearer file: {str(bearer_file)} ")
-            login_gateway_failed = False
-        else:
-            etld_lib_functions.logger.error(f"Fail - Qualys Gateway Login Failed with user: {cred_dict['username']}")
-            etld_lib_functions.logger.error(f"       HTTP {response.status_code}")
-            etld_lib_functions.logger.error(f"       Verify Qualys username, password and "
-                                            f"gateway_fqdn_server in Credentials File")
-            etld_lib_functions.logger.error(f"             Credentials File: {cred_file}")
-            etld_lib_functions.logger.error(f"             username:         {cred_dict['username']}")
-            etld_lib_functions.logger.error(f"             api_fqdn_server:  {cred_dict['api_fqdn_server']}")
-            etld_lib_functions.logger.error(f"         gateway_fqdn_server:  {cred_dict['gateway_fqdn_server']}")
-            exit(1)
-    except requests.exceptions.RequestException as e:
-        etld_lib_functions.logger.error(f"Fail - Qualys Gateway Login Failed with user: {cred_dict['username']}")
-        etld_lib_functions.logger.error(f"       Verify Qualys username, password and "
-                                        f"api_fqdn_server, and gateway_fqdn_server in Credentials File")
-        etld_lib_functions.logger.error(f"             Credentials File: {cred_file}")
-        etld_lib_functions.logger.error(f"             username:         {cred_dict['username']}")
-        etld_lib_functions.logger.error(f"             api_fqdn_server:  {cred_dict['api_fqdn_server']}")
-        etld_lib_functions.logger.error(f"         gateway_fqdn_server:  {cred_dict['gateway_fqdn_server']}")
-        etld_lib_functions.logger.error(f"Exception: {e}")
-        exit(1)
+# def qualys_gateway_login():
+#     global login_gateway_failed
+#     global http_return_code
+#
+#     login_gateway_failed = True
+#     cred_dict = get_cred()
+#     if cred_dict['gateway_fqdn_server'] is None:
+#         etld_lib_functions.logger.error(f"Please add gateway_fqdn_server to your credentials file.")
+#         exit(1)
+#
+#     # Login to Qualys, return bearer token.
+#     url = f"https://{cred_dict['gateway_fqdn_server']}/auth"  # Qualys Endpoint
+#     payload = {'token': 'true', 'password': cred_dict['password'], 'username': cred_dict['username'],
+#                'permissions': 'true'}
+#     payload = urlencode(payload, quote_via=quote_plus)
+#
+#     headers = {'X-Requested-With': f'qualysetl_v{qualys_etl.__version__}',
+#                'Content-Type': 'application/x-www-form-urlencoded',
+#                'User-Agent': f"qualysetl_v{qualys_etl.__version__}"}
+#
+#     try:
+#         if Path(bearer_file).is_file():
+#             Path(bearer_file).unlink()
+#         response = requests.request("POST", url, headers=headers, data=payload,
+#                                     verify=etld_lib_config.requests_module_tls_verify_status)
+#         http_return_code = response.status_code
+#         if response.status_code == 201:
+#             bearer = f"Bearer {response.text}"
+#             with open(bearer_file, 'w', encoding='utf-8') as bearerfile:
+#                 bearerfile.write(bearer)
+#             oschmod.set_mode(str(bearer_file), "u+rw,u-x,go-rwx")
+#             etld_lib_functions.logger.info(f"LOGIN - Qualys Gateway Login Success with user: {cred_dict['username']}")
+#             bearer_file_mode = stat.filemode(os.stat(bearer_file).st_mode)
+#             etld_lib_functions.logger.info(f"Bearer Set, Ensure perms are correct for your company. "
+#                                            f"permissions: {bearer_file_mode}, bearer file: {str(bearer_file)} ")
+#             login_gateway_failed = False
+#         else:
+#             etld_lib_functions.logger.error(f"Fail - Qualys Gateway Login Failed with user: {cred_dict['username']}")
+#             etld_lib_functions.logger.error(f"       HTTP {response.status_code}")
+#             etld_lib_functions.logger.error(f"       Verify Qualys username, password and "
+#                                             f"gateway_fqdn_server in Credentials File")
+#             etld_lib_functions.logger.error(f"             Credentials File: {cred_file}")
+#             etld_lib_functions.logger.error(f"             username:         {cred_dict['username']}")
+#             etld_lib_functions.logger.error(f"             api_fqdn_server:  {cred_dict['api_fqdn_server']}")
+#             etld_lib_functions.logger.error(f"         gateway_fqdn_server:  {cred_dict['gateway_fqdn_server']}")
+#             exit(1)
+#     except requests.exceptions.RequestException as e:
+#         etld_lib_functions.logger.error(f"Fail - Qualys Gateway Login Failed with user: {cred_dict['username']}")
+#         etld_lib_functions.logger.error(f"       Verify Qualys username, password and "
+#                                         f"api_fqdn_server, and gateway_fqdn_server in Credentials File")
+#         etld_lib_functions.logger.error(f"             Credentials File: {cred_file}")
+#         etld_lib_functions.logger.error(f"             username:         {cred_dict['username']}")
+#         etld_lib_functions.logger.error(f"             api_fqdn_server:  {cred_dict['api_fqdn_server']}")
+#         etld_lib_functions.logger.error(f"         gateway_fqdn_server:  {cred_dict['gateway_fqdn_server']}")
+#         etld_lib_functions.logger.error(f"Exception: {e}")
+#         exit(1)
 
 
 def get_bearer_stored_in_env(update_bearer=True, cred={}):
-    one_hour = 360
+    max_age_of_bearer_token = 900
     try:
         if update_bearer:
             cred = qualys_gateway_login_store_in_env(cred_dict=cred)
@@ -362,8 +362,9 @@ def get_bearer_stored_in_env(update_bearer=True, cred={}):
             cred = qualys_gateway_login_store_in_env(cred_dict=cred)
         elif Path(bearer_file).is_file():
             age_of_file = etld_lib_datetime.get_seconds_since_last_file_modification(Path(bearer_file))
-            if age_of_file > one_hour:
+            if age_of_file > max_age_of_bearer_token:
                 cred = qualys_gateway_login_store_in_env(cred_dict=cred)
+                etld_lib_functions.logger.info(f"Updated Bearer Token Successfully. age_of_file={age_of_file}, max_age={max_age_of_bearer_token}")
         else:
             cred = qualys_gateway_login_store_in_env(cred_dict=cred)
 
@@ -376,6 +377,29 @@ def get_bearer_stored_in_env(update_bearer=True, cred={}):
     return cred
 
 
+def update_cred_dict(response, cred_dict) -> dict:
+    with open(bearer_file, 'w', encoding='utf-8') as bearerfile:
+        bearerfile.write(f"DUMMY ENTRY FOR TIME TRACKING OF BEARER AGE")
+    bearer = f"Bearer {response.text}"
+    cred_dict['bearer'] = bearer
+    oschmod.set_mode(str(bearer_file), "u+rw,u-x,go-rwx")
+    etld_lib_functions.logger.info(f"LOGIN - Qualys Gateway Login Success with user: {cred_dict['username']}")
+    return cred_dict
+
+
+def qualys_gateway_login_failed_message(response, cred_dict, log_level, message=""):
+    if response != "":
+        response_message = f", HTTP RESPONSE CODE: {response.status_code}"
+    else:
+        response_message = ""
+
+    log_level(f"Qualys Gateway Login Failed with user: {cred_dict['username']} {response_message}")
+    log_level(f"{message}")
+    log_level(f"Credentials Env: username:{cred_dict['username']},"
+              f"api_fqdn_server:{cred_dict['api_fqdn_server']},"
+              f"gateway_fqdn_server:{cred_dict['gateway_fqdn_server']}")
+
+
 def qualys_gateway_login_store_in_env(cred_dict={}):
     global login_gateway_failed
     global http_return_code
@@ -395,39 +419,44 @@ def qualys_gateway_login_store_in_env(cred_dict={}):
     headers = {'X-Requested-With': f'qualysetl_v{qualys_etl.__version__}',
                'Content-Type': 'application/x-www-form-urlencoded',
                'User-Agent': f"qualysetl_v{qualys_etl.__version__}"}
-
-    try:
-        response = requests.request("POST", url, headers=headers, data=payload,
-                                    verify=etld_lib_config.requests_module_tls_verify_status)
-        http_return_code = response.status_code
-        if response.status_code == 201:
-            with open(bearer_file, 'w', encoding='utf-8') as bearerfile:
-                bearerfile.write(f"DUMMY ENTRY FOR TIME TRACKING OF BEARER AGE")
-            bearer = f"Bearer {response.text}"
-            cred_dict['bearer'] = bearer
-            oschmod.set_mode(str(bearer_file), "u+rw,u-x,go-rwx")
-            etld_lib_functions.logger.info(f"LOGIN - Qualys Gateway Login Success with user: {cred_dict['username']}")
-            login_gateway_failed = False
-        else:
-            etld_lib_functions.logger.error(f"Fail - Qualys Gateway Login Failed with user: {cred_dict['username']}")
-            etld_lib_functions.logger.error(f"       HTTP {response.status_code}")
-            etld_lib_functions.logger.error(f"       Verify Qualys username, password and "
-                                            f"gateway_fqdn_server in Credentials File or environment")
-            etld_lib_functions.logger.error(f"             Credentials Env:")
-            etld_lib_functions.logger.error(f"             username:         {cred_dict['username']}")
-            etld_lib_functions.logger.error(f"             api_fqdn_server:  {cred_dict['api_fqdn_server']}")
-            etld_lib_functions.logger.error(f"         gateway_fqdn_server:  {cred_dict['gateway_fqdn_server']}")
-            exit(1)
-    except requests.exceptions.RequestException as e:
-        etld_lib_functions.logger.error(f"Fail - Qualys Gateway Login Failed with user: {cred_dict['username']}")
-        etld_lib_functions.logger.error(f"       Verify Qualys username, password and "
-                                        f"api_fqdn_server, and gateway_fqdn_server in Credentials File")
-        etld_lib_functions.logger.error(f"             Credentials Env:")
-        etld_lib_functions.logger.error(f"             username:         {cred_dict['username']}")
-        etld_lib_functions.logger.error(f"             api_fqdn_server:  {cred_dict['api_fqdn_server']}")
-        etld_lib_functions.logger.error(f"         gateway_fqdn_server:  {cred_dict['gateway_fqdn_server']}")
-        etld_lib_functions.logger.error(f"Exception: {e}")
-        exit(1)
+    max_retries = 5
+    sleep_time = 10
+    for retry_number in range(max_retries):
+        try:
+            response = requests.request("POST", url, headers=headers, data=payload,
+                                        verify=etld_lib_config.requests_module_tls_verify_status)
+            http_return_code = response.status_code
+            if response.status_code == 503:  # 503:  # Service Temporarily Unavailable
+                qualys_gateway_login_failed_message(
+                    message=f"Retry number {retry_number} for HTTP Response Code: {response.status_code} ",
+                    response=response,
+                    cred_dict=cred_dict,
+                    log_level=etld_lib_functions.logger.warning)
+                time.sleep(sleep_time)
+            elif response.status_code == 201:
+                cred_dict = update_cred_dict(response, cred_dict)
+                login_gateway_failed = False
+                break
+            else:
+                qualys_gateway_login_failed_message(
+                    message=f"HTTP Response Code: {response.status_code} ",
+                    response=response,
+                    cred_dict=cred_dict,
+                    log_level=etld_lib_functions.logger.error)
+                exit(1)
+        except requests.exceptions.RequestException as e:
+            qualys_gateway_login_failed_message(
+                message=f"Requests Module Failed ",
+                response="",
+                cred_dict=cred_dict,
+                log_level=etld_lib_functions.logger.error)
+            etld_lib_functions.logger.error(f"Exception: {e}")
+            exit(2)
+    else:
+        qualys_gateway_login_failed_message(response="",
+                                            cred_dict=cred_dict,
+                                            log_level=etld_lib_functions.logger.error)
+        exit(3)
 
     return cred_dict
 
@@ -524,8 +553,8 @@ def test_basic_auth():
     time.sleep(0.5)
 
 
-def test_gateway_auth():
-    qualys_gateway_login()
+# def test_gateway_auth():
+#     qualys_gateway_login()
 
 
 if __name__ == '__main__':
